import logging

from autogen_agentchat.agents import AssistantAgent
from autogen_agentchat.conditions import MaxMessageTermination, TextMentionTermination
from autogen_agentchat.teams import RoundRobinGroupChat
from autogen_core.tools import FunctionTool
from mtmaisdk.clients.rest.models.model_config import ModelConfig

from mtmai.tools.calculator import web_search

from mtmai.agents._agents import MtRoundRobinGroupChat
from ..model_client import MtmOpenAIChatCompletionClient, get_oai_Model

logger = logging.getLogger(__name__)

class AssistantTeamBuilder:
    """默认聊天团队"""
    async def create_team(self, model_config: ModelConfig):
        """创建旅行助理"""

        model_dict = model_config.model_dump()
        model_dict["model_info"] = model_dict.pop("model_info", None)
        model_dict.pop("n", None)
        model_client = MtmOpenAIChatCompletionClient(
            **model_dict,

        )
        planner_agent = AssistantAgent(
            name="planner_agent",
            model_client=model_client,
            description="A helpful assistant that can plan trips.",
            system_message="You are a helpful assistant that can suggest a travel plan for a user based on their request.",
        )

        local_agent = AssistantAgent(
            name="local_agent",
            model_client=model_client,
            description="A local assistant that can suggest local activities or places to visit.",
            system_message="You are a helpful assistant that can suggest authentic and interesting local activities or places to visit for a user and can utilize any context information provided.",
        )

        language_agent = AssistantAgent(
            name="language_agent",
            model_client=model_client,
            description="A helpful assistant that can provide language tips for a given destination.",
            system_message="You are a helpful assistant that can review travel plans, providing feedback on important/critical tips about how best to address language or communication challenges for the given destination. If the plan already includes language tips, you can mention that the plan is satisfactory, with rationale.",
        )

        travel_summary_agent = AssistantAgent(
            name="travel_summary_agent",
            model_client=model_client,
            description="A helpful assistant that can summarize the travel plan.",
            system_message="You are a helpful assistant that can take in all of the suggestions and advice from the other agents and provide a detailed final travel plan. You must ensure that the final plan is integrated and complete. YOUR FINAL RESPONSE MUST BE THE COMPLETE PLAN. When the plan is complete and all perspectives are integrated, you can respond with TERMINATE.",
        )

        termination = TextMentionTermination(text="TERMINATE")
        max_msg_termination = MaxMessageTermination(max_messages=5)
        combined_termination = max_msg_termination & termination
        team = MtRoundRobinGroupChat(
            participants=[
                # user_proxy_agent,
                planner_agent,
                local_agent,
                language_agent,
                travel_summary_agent,
            ],
            termination_condition=combined_termination,
        )
        team.component_version = 2
        team.component_label = "default_chat_team"
        team.component_description = "默认聊天团队"
        return team
